@@ -4,8 +4,17 @@ consistent access method for settings defined in applications, the project
 or Django itself. Settings can also be made editable via the admin.
 """
 
+from __future__ import unicode_literals
+from warnings import warn
+from functools import partial
+from future.builtins import bytes, str
+
 from django.conf import settings as django_settings
-from django.utils.encoding import force_unicode
+try:
+    from django.utils.encoding import force_text
+except ImportError:
+    # Backward compatibility for Py2 and Django < 1.5
+    from django.utils.encoding import force_unicode as force_text
 from django.utils.functional import Promise
 from django.utils.importlib import import_module
 from django.utils.module_loading import module_has_submodule
@@ -34,12 +43,23 @@ def register_setting(name="", label="", editable=False, description="",
         if hasattr(django_settings, name):
             editable = False
         if isinstance(default, Promise):
-            default = force_unicode(default)
-        setting_type = type(default)
+            default = force_text(default)
         if not label:
             label = name.replace("_", " ").title()
-        if setting_type is str:
-            setting_type = unicode
+        # The next six lines are for Python 2/3 compatibility.
+        # isinstance() is overridden by future on Python 2 to behave as
+        # on Python 3 in conjunction with either Python 2's native types
+        # or the future.builtins types.
+        if isinstance(default, bool):       # prevent bools treated as ints
+            setting_type = bool
+        elif isinstance(default, int):      # an int or long or subclass on Py2
+            setting_type = int
+        elif isinstance(default, str):      # a unicode or subclass on Py2
+            setting_type = str
+        elif isinstance(default, bytes):    # a byte-string or subclass on Py2
+            setting_type = bytes
+        else:
+            setting_type = type(default)
         registry[name] = {"name": name, "label": label,
                           "description": description,
                           "editable": editable, "default": default,
@@ -64,6 +84,14 @@ class Settings(object):
     of access for all settings.
     """
 
+    # These functions map setting types to the functions that should be
+    # used to convert them from the Unicode string stored in the database.
+    # If a type doesn't appear in this map, the type itself will be used.
+    TYPE_FUNCTIONS = {
+        bool: lambda val: val != "False",
+        bytes: partial(bytes, encoding='utf8')
+    }
+
     def __init__(self):
         """
         The ``_loaded`` attribute is a flag for defining whether
@@ -89,6 +117,57 @@ class Settings(object):
         self._loaded = __name__ not in getattr(self, "INSTALLED_APPS")
         self._editable_cache = {}
 
+    def _load(self):
+        """
+        Load settings from the database into cache. Delete any settings from
+        the database that are no longer registered, and emit a warning if
+        there are settings that are defined in settings.py and the database.
+        """
+        from mezzanine.conf.models import Setting
+
+        removed_settings = []
+        conflicting_settings = []
+
+        for setting_obj in Setting.objects.all():
+
+            try:
+                registry[setting_obj.name]
+            except KeyError:
+                # Setting in DB isn't registered (removed from code),
+                # so add to removal list and skip remaining handling.
+                removed_settings.append(setting_obj.name)
+                continue
+
+            # Convert DB value to correct type.
+            setting_type = registry[setting_obj.name]["type"]
+            type_fn = self.TYPE_FUNCTIONS.get(setting_type, setting_type)
+            try:
+                setting_value = type_fn(setting_obj.value)
+            except ValueError:
+                # Shouldn't occur, but just a safeguard
+                # for if the db value somehow ended up as
+                # an invalid type.
+                setting_value = registry[setting_obj.name]["default"]
+
+            # Only use DB setting if it's not defined in settings.py
+            # module, in which case add it to conflicting list for
+            # warning.
+            try:
+                getattr(django_settings, setting_obj.name)
+            except AttributeError:
+                self._editable_cache[setting_obj.name] = setting_value
+            else:
+                if setting_value != registry[setting_obj.name]["default"]:
+                    conflicting_settings.append(setting_obj.name)
+
+        if removed_settings:
+            Setting.objects.filter(name__in=removed_settings).delete()
+        if conflicting_settings:
+            warn("These settings are defined in both settings.py and "
+                 "the database: %s. The settings.py values will be used."
+                 % ", ".join(conflicting_settings))
+        self._loaded = True
+
     def __getattr__(self, name):
 
         # Lookup name as a registered setting or a Django setting.
@@ -98,32 +177,8 @@ class Settings(object):
             return getattr(django_settings, name)
 
         # First access for an editable setting - load from DB into cache.
-        # Also remove settings from the DB that are no longer registered.
         if setting["editable"] and not self._loaded:
-            from mezzanine.conf.models import Setting
-            settings = Setting.objects.all()
-            removed = []
-            for setting_obj in settings:
-                try:
-                    setting_type = registry[setting_obj.name]["type"]
-                except KeyError:
-                    removed.append(setting_obj.id)
-                else:
-                    if setting_type is bool:
-                        setting_value = setting_obj.value != "False"
-                    else:
-                        try:
-                            setting_value = setting_type(setting_obj.value)
-                        except ValueError:
-                            # Shouldn't occur, but just a safeguard
-                            # for if the db value somehow ended up as
-                            # an invalid type.
-                            default = registry[setting_obj.name]["default"]
-                            setting_value = default
-                    self._editable_cache[setting_obj.name] = setting_value
-            if removed:
-                Setting.objects.filter(id__in=removed).delete()
-            self._loaded = True
+            self._load()
 
         # Use cached editable setting if found, otherwise use the
         # value defined in the project's settings.py module if it
