@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 
 from django.core.exceptions import ImproperlyConfigured
 from django import forms
@@ -81,8 +82,8 @@ DATES = (DATE, DATE_TIME, DOB)
 MULTIPLE = (CHECKBOX_MULTIPLE, SELECT_MULTIPLE)
 
 # HTML5 Widgets
-if settings.FORMS_USE_HTML5:
-    html5_field = lambda name, base: type("", (base,), {"input_type": name})
+html5_field = lambda name, base: type(str(""), (base,), {"input_type": name})
+if getattr(settings, "FORMS_USE_HTML5", False):
     WIDGETS.update({
         DATE: html5_field("date", forms.DateInput),
         DATE_TIME: html5_field("datetime", forms.DateTimeInput),
@@ -96,7 +97,8 @@ if settings.FORMS_USE_HTML5:
 # setting, which should contain a sequence of three-item sequences,
 # each containing the ID, dotted import path for the field class,
 # and field name, for each custom field type.
-for field_id, field_path, field_name in settings.FORMS_EXTRA_FIELDS:
+extra_fields = getattr(settings, "FORMS_EXTRA_FIELDS", [])
+for field_id, field_path, field_name in extra_fields:
     if field_id in CLASSES:
         err = "ID %s for field %s in FORMS_EXTRA_FIELDS already exists"
         raise ImproperlyConfigured(err % (field_id, field_name))
