@@ -1,13 +1,20 @@
+from __future__ import unicode_literals
+from future.builtins import str
+from future.utils import native, PY2
 
-from cStringIO import StringIO
+from io import BytesIO
 import os
 from string import punctuation
-from urllib import unquote
+try:
+    from urllib.parse import unquote
+except ImportError:     # Python 2
+    from urllib import unquote
 from zipfile import ZipFile
 
 from django.core.files.base import ContentFile
 from django.core.files.storage import default_storage
 from django.db import models
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.conf import settings
@@ -60,15 +67,20 @@ class Gallery(Page, RichText):
             for name in zip_file.namelist():
                 data = zip_file.read(name)
                 try:
-                    image = Image.open(StringIO(data))
+                    image = Image.open(BytesIO(data))
                     image.load()
-                    image = Image.open(StringIO(data))
+                    image = Image.open(BytesIO(data))
                     image.verify()
                 except:
                     continue
                 name = os.path.split(name)[1]
-                path = os.path.join(GALLERIES_UPLOAD_DIR, self.slug,
-                                    name.decode("utf-8"))
+                # This is a way of getting around the broken nature of
+                # os.path.join on Python 2.x. See also the comment below.
+                if PY2:
+                    tempname = name.decode('utf-8')
+                else:
+                    tempname = name
+                path = os.path.join(GALLERIES_UPLOAD_DIR, self.slug, tempname)
                 try:
                     saved_path = default_storage.save(path, ContentFile(data))
                 except UnicodeEncodeError:
@@ -77,8 +89,13 @@ class Gallery(Page, RichText):
                          "characters in its path, but somehow the current "
                          "locale does not support utf-8. You may need to set "
                          "'LC_ALL' to a correct value, eg: 'en_US.UTF-8'.")
+                    # The native() call is needed here around str because
+                    # os.path.join() in Python 2.x (in posixpath.py)
+                    # mixes byte-strings with unicode strings without
+                    # explicit conversion, which raises a TypeError as it
+                    # would on Python 3.
                     path = os.path.join(GALLERIES_UPLOAD_DIR, self.slug,
-                                        unicode(name, errors="ignore"))
+                                        native(str(name, errors="ignore")))
                     saved_path = default_storage.save(path, ContentFile(data))
                 self.images.add(GalleryImage(file=saved_path))
             if delete_zip_import:
@@ -86,6 +103,7 @@ class Gallery(Page, RichText):
                 self.zip_import.delete(save=True)
 
 
+@python_2_unicode_compatible
 class GalleryImage(Orderable):
 
     gallery = models.ForeignKey("Gallery", related_name="images")
@@ -98,7 +116,7 @@ class GalleryImage(Orderable):
         verbose_name = _("Image")
         verbose_name_plural = _("Images")
 
-    def __unicode__(self):
+    def __str__(self):
         return self.description
 
     def save(self, *args, **kwargs):
