@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from future.builtins import str
 
 from collections import defaultdict
 
@@ -7,7 +9,7 @@ from django.template.loader import get_template
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.pages.models import Page
-from mezzanine.utils.urls import admin_url, home_slug
+from mezzanine.utils.urls import home_slug
 from mezzanine import template
 
 
@@ -28,7 +30,7 @@ def page_menu(context, token):
     parts = token.split_contents()[1:]
     for part in parts:
         part = Variable(part).resolve(context)
-        if isinstance(part, unicode):
+        if isinstance(part, str):
             template_name = part
         elif isinstance(part, Page):
             parent_page = part
@@ -48,12 +50,8 @@ def page_menu(context, token):
             slug = ""
         num_children = lambda id: lambda: len(context["menu_pages"][id])
         has_children = lambda id: lambda: num_children(id)() > 0
-        published = Page.objects.published(for_user=user)
-        if slug == admin_url(Page, "changelist"):
-            related = [m.__name__.lower() for m in Page.get_content_models()]
-            published = published.select_related(*related)
-        else:
-            published = published.select_related(depth=2)
+        rel = [m.__name__.lower() for m in Page.get_content_models()]
+        published = Page.objects.published(for_user=user).select_related(*rel)
         # Store the current page being viewed in the context. Used
         # for comparisons in page.set_menu_helpers.
         if "page" not in context:
@@ -179,7 +177,7 @@ def set_page_permissions(context, token):
         opts = model._meta
     except AttributeError:
         if model is None:
-            error = _("Could not load the model for the following page,"
+            error = _("Could not load the model for the following page, "
                       "was it removed?")
             obj = page
         else:
